==> jc-1.4.0.tar.gz: javax/swing/text/PlainDocument.h <==
// public class javax.swing.text.PlainDocument

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f18f81e7a4015d34 javax_swing_text_AbstractDocument
// @dep_class 4d7369a3384b204a javax_swing_text_PlainDocument

// header file dependencies
// @dep_header javax_swing_text_AbstractDocument

#include "javax/swing/text/AbstractDocument.h"

#ifndef _JC_javax_swing_text_PlainDocument_H_
#define _JC_javax_swing_text_PlainDocument_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_text_AbstractDocument__24AbstractElement$object;
struct _jc_javax_swing_text_AbstractDocument__24Content$object;
struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object;
struct _jc_javax_swing_text_AttributeSet$object;
struct _jc_javax_swing_text_Element$object;

// Typedefs
typedef struct _jc_javax_swing_text_PlainDocument$sub_refs	_jc_javax_swing_text_PlainDocument$sub_refs;
typedef struct _jc_javax_swing_text_PlainDocument$sub_nonrefs	_jc_javax_swing_text_PlainDocument$sub_nonrefs;
typedef struct _jc_javax_swing_text_PlainDocument$refs	_jc_javax_swing_text_PlainDocument$refs;
typedef struct _jc_javax_swing_text_PlainDocument$nonrefs	_jc_javax_swing_text_PlainDocument$nonrefs;
typedef struct _jc_javax_swing_text_PlainDocument$object	_jc_javax_swing_text_PlainDocument$object;

typedef struct _jc_javax_swing_text_PlainDocument$fields_struct	_jc_javax_swing_text_PlainDocument$fields_struct;
typedef const struct _jc_javax_swing_text_PlainDocument$vmethods	_jc_javax_swing_text_PlainDocument$vmethods;
typedef const struct _jc_javax_swing_text_PlainDocument$vtable	_jc_javax_swing_text_PlainDocument$vtable;
typedef const struct _jc_javax_swing_text_PlainDocument$vtype	_jc_javax_swing_text_PlainDocument$vtype;

// Class fields structure
struct _jc_javax_swing_text_PlainDocument$fields_struct {
	struct _jc_java_lang_String$object	*lineLimitAttribute;
	struct _jc_java_lang_String$object	*tabSizeAttribute;
	jlong	serialVersionUID;
};
extern _jc_javax_swing_text_PlainDocument$fields_struct _jc_javax_swing_text_PlainDocument$class_fields;

// Constructors
extern void _jc_javax_swing_text_PlainDocument$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *);
extern void _jc_javax_swing_text_PlainDocument$method$_init$df8203bc9208de35(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_javax_swing_text_AbstractDocument__24AbstractElement$object *_jc_javax_swing_text_PlainDocument$method$createDefaultRoot$59dfdd1e9a6a71f8(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *);
extern struct _jc_object *_jc_javax_swing_text_PlainDocument$method$getDefaultRootElement$2a15ba2db2fe4631(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *);
extern struct _jc_object *_jc_javax_swing_text_PlainDocument$method$getParagraphElement$4cc343ba97d4b7d5(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *, jint);
extern void _jc_javax_swing_text_PlainDocument$method$insertUpdate$06d195e59b54bc20(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *, struct _jc_object *);
extern void _jc_javax_swing_text_PlainDocument$method$reindex$0378ce6b53a29cdc(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *);
extern void _jc_javax_swing_text_PlainDocument$method$removeUpdate$7ef115a4f54e9f2d(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_PlainDocument$method_info$createDefaultRoot$59dfdd1e9a6a71f8;
extern _jc_method _jc_javax_swing_text_PlainDocument$method_info$getDefaultRootElement$2a15ba2db2fe4631;
extern _jc_method _jc_javax_swing_text_PlainDocument$method_info$getParagraphElement$4cc343ba97d4b7d5;
extern _jc_method _jc_javax_swing_text_PlainDocument$method_info$insertUpdate$06d195e59b54bc20;
extern _jc_method _jc_javax_swing_text_PlainDocument$method_info$reindex$0378ce6b53a29cdc;
extern _jc_method _jc_javax_swing_text_PlainDocument$method_info$removeUpdate$7ef115a4f54e9f2d;

// Virtual methods structure
struct _jc_javax_swing_text_PlainDocument$vmethods {
	struct _jc_javax_swing_text_AbstractDocument__24AbstractElement$object	*(*createDefaultRoot$59dfdd1e9a6a71f8)(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *);
	struct _jc_object	*(*getDefaultRootElement$2a15ba2db2fe4631)(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *);
	struct _jc_object	*(*getParagraphElement$4cc343ba97d4b7d5)(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *, jint);
	void	(*insertUpdate$06d195e59b54bc20)(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *, struct _jc_object *);
	void	(*reindex$0378ce6b53a29cdc)(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *);
	void	(*removeUpdate$7ef115a4f54e9f2d)(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *);
};

// Vtable
struct _jc_javax_swing_text_PlainDocument$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_AbstractDocument$vmethods	javax_swing_text_AbstractDocument;
	_jc_javax_swing_text_PlainDocument$vmethods	javax_swing_text_PlainDocument;
};

// Vtype
struct _jc_javax_swing_text_PlainDocument$vtype {
	_jc_type			type;
	_jc_javax_swing_text_PlainDocument$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_PlainDocument$sub_refs {
	struct _jc_object	*rootElement;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_PlainDocument$refs {
    _jc_javax_swing_text_PlainDocument$sub_refs	javax_swing_text_PlainDocument;
    _jc_javax_swing_text_AbstractDocument$sub_refs	javax_swing_text_AbstractDocument;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_PlainDocument$sub_nonrefs {
	jint	tabSize;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_PlainDocument$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_AbstractDocument$sub_nonrefs	javax_swing_text_AbstractDocument;
    _jc_javax_swing_text_PlainDocument$sub_nonrefs	javax_swing_text_PlainDocument;
};

// Object instance structure
struct _jc_javax_swing_text_PlainDocument$object {
	_jc_javax_swing_text_PlainDocument$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_PlainDocument$vtype	*vtype;
	_jc_javax_swing_text_PlainDocument$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_PlainDocument$vtype _jc_javax_swing_text_PlainDocument$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_PlainDocument, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_PlainDocument$class_object;

#endif	/* _JC_javax_swing_text_PlainDocument_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/PlainDocument.h <==
// public class javax.swing.text.PlainDocument

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 189d612f9aa3441e javax_swing_text_AbstractDocument
// @dep_class 4d7369a3384b204a javax_swing_text_PlainDocument

// header file dependencies
// @dep_header javax_swing_text_AbstractDocument

#include "javax/swing/text/AbstractDocument.h"

#ifndef _JC_javax_swing_text_PlainDocument_H_
#define _JC_javax_swing_text_PlainDocument_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_javax_swing_text_AbstractDocument__24AbstractElement$object;
struct _jc_javax_swing_text_AbstractDocument__24Content$object;
struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object;
struct _jc_javax_swing_text_AttributeSet$object;
struct _jc_javax_swing_text_Element$object;

// Typedefs
typedef struct _jc_javax_swing_text_PlainDocument$sub_refs	_jc_javax_swing_text_PlainDocument$sub_refs;
typedef struct _jc_javax_swing_text_PlainDocument$sub_nonrefs	_jc_javax_swing_text_PlainDocument$sub_nonrefs;
typedef struct _jc_javax_swing_text_PlainDocument$refs	_jc_javax_swing_text_PlainDocument$refs;
typedef struct _jc_javax_swing_text_PlainDocument$nonrefs	_jc_javax_swing_text_PlainDocument$nonrefs;
typedef struct _jc_javax_swing_text_PlainDocument$object	_jc_javax_swing_text_PlainDocument$object;

typedef struct _jc_javax_swing_text_PlainDocument$fields_struct	_jc_javax_swing_text_PlainDocument$fields_struct;
typedef const struct _jc_javax_swing_text_PlainDocument$vmethods	_jc_javax_swing_text_PlainDocument$vmethods;
typedef const struct _jc_javax_swing_text_PlainDocument$vtable	_jc_javax_swing_text_PlainDocument$vtable;
typedef const struct _jc_javax_swing_text_PlainDocument$vtype	_jc_javax_swing_text_PlainDocument$vtype;

// Class fields structure
struct _jc_javax_swing_text_PlainDocument$fields_struct {
	struct _jc_java_lang_String$object	*lineLimitAttribute;
	struct _jc_java_lang_String$object	*tabSizeAttribute;
	jlong	serialVersionUID;
};
extern _jc_javax_swing_text_PlainDocument$fields_struct _jc_javax_swing_text_PlainDocument$class_fields;

// Constructors
extern void _jc_javax_swing_text_PlainDocument$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_PlainDocument$method$_init$df8203bc9208de35(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_swing_text_AbstractDocument__24AbstractElement$object *_jc_javax_swing_text_PlainDocument$method$createDefaultRoot$59dfdd1e9a6a71f8(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_text_PlainDocument$method$getDefaultRootElement$2a15ba2db2fe4631(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_swing_text_PlainDocument$method$getParagraphElement$4cc343ba97d4b7d5(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *, jint) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_PlainDocument$method$insertUpdate$06d195e59b54bc20(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_PlainDocument$method$reindex$0378ce6b53a29cdc(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_PlainDocument$method$removeUpdate$7ef115a4f54e9f2d(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_PlainDocument$method_info$createDefaultRoot$59dfdd1e9a6a71f8;
extern _jc_method _jc_javax_swing_text_PlainDocument$method_info$getDefaultRootElement$2a15ba2db2fe4631;
extern _jc_method _jc_javax_swing_text_PlainDocument$method_info$getParagraphElement$4cc343ba97d4b7d5;
extern _jc_method _jc_javax_swing_text_PlainDocument$method_info$insertUpdate$06d195e59b54bc20;
extern _jc_method _jc_javax_swing_text_PlainDocument$method_info$reindex$0378ce6b53a29cdc;
extern _jc_method _jc_javax_swing_text_PlainDocument$method_info$removeUpdate$7ef115a4f54e9f2d;

// Virtual methods structure
struct _jc_javax_swing_text_PlainDocument$vmethods {
	struct _jc_javax_swing_text_AbstractDocument__24AbstractElement$object	*(*createDefaultRoot$59dfdd1e9a6a71f8)(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getDefaultRootElement$2a15ba2db2fe4631)(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getParagraphElement$4cc343ba97d4b7d5)(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *, jint) _JC_JCNI_ATTR;
	void	(*insertUpdate$06d195e59b54bc20)(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*reindex$0378ce6b53a29cdc)(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *) _JC_JCNI_ATTR;
	void	(*removeUpdate$7ef115a4f54e9f2d)(_jc_env *, struct _jc_javax_swing_text_PlainDocument$object *, struct _jc_javax_swing_text_AbstractDocument__24DefaultDocumentEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_PlainDocument$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_text_AbstractDocument$vmethods	javax_swing_text_AbstractDocument;
	_jc_javax_swing_text_PlainDocument$vmethods	javax_swing_text_PlainDocument;
};

// Vtype
struct _jc_javax_swing_text_PlainDocument$vtype {
	_jc_type			type;
	_jc_javax_swing_text_PlainDocument$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_PlainDocument$sub_refs {
	struct _jc_object	*rootElement;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_PlainDocument$refs {
    _jc_javax_swing_text_PlainDocument$sub_refs	javax_swing_text_PlainDocument;
    _jc_javax_swing_text_AbstractDocument$sub_refs	javax_swing_text_AbstractDocument;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_PlainDocument$sub_nonrefs {
	jint	tabSize;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_PlainDocument$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_text_AbstractDocument$sub_nonrefs	javax_swing_text_AbstractDocument;
    _jc_javax_swing_text_PlainDocument$sub_nonrefs	javax_swing_text_PlainDocument;
};

// Object instance structure
struct _jc_javax_swing_text_PlainDocument$object {
	_jc_javax_swing_text_PlainDocument$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_PlainDocument$vtype	*vtype;
	_jc_javax_swing_text_PlainDocument$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_PlainDocument$vtype _jc_javax_swing_text_PlainDocument$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_PlainDocument, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_PlainDocument$class_object;

#endif	/* _JC_javax_swing_text_PlainDocument_H_ */
